# Credits

## Development Lead

- Jack Linke <jack@watervize.com>

## Contributors

- Adam Johnson ([@AdamChainz](https://twitter.com/AdamChainz)) ❤️
- Niccolò Mineo ([@niccolomineo](https://twitter.com/niccolomineo)) 💙
